package com.discovergy.apiclient.examples;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutionException;
import java.util.function.Consumer;

import com.discovergy.apiclient.DiscovergyApiClient;
import com.github.scribejava.core.model.OAuthRequest;
import com.github.scribejava.core.model.Verb;

import flexjson.JSONSerializer;

public class AlertsExample {

	private static final String METER_ID = "EASYMETER_1024000034";

	public static void main(String[] args) throws Exception {
		DiscovergyApiClient apiClient = new DiscovergyApiClient("exampleApiClient");

		addAlert(apiClient, properties -> {
			properties.put("alertType", "OFFLINE");
			properties.put("duration", 4);
			properties.put("durationUnit", "HOURS");
			properties.put("apiEndpoint", "https://www.example.com/alert");
		});

		addAlert(apiClient, properties -> {
			properties.put("alertType", "POWER_THRESHOLD");
			properties.put("duration", 10);
			properties.put("durationUnit", "MINUTES");
			properties.put("threshold", 3000);
			properties.put("thresholdType", "UPPER");
		});

		addAlert(apiClient, properties -> {
			properties.put("alertType", "ENERGY_THRESHOLD");
			properties.put("duration", 7);
			properties.put("durationUnit", "CALENDAR_DAYS");
			properties.put("threshold", 50);
			properties.put("thresholdType", "UPPER");
		});
	}

	private static void addAlert(DiscovergyApiClient apiClient, Consumer<Map<String, Object>> propertiesFiller)
			throws InterruptedException, ExecutionException, IOException {
		OAuthRequest request = apiClient.createRequest(Verb.POST, "/alert");
		Map<String, Object> properties = new HashMap<>();
		propertiesFiller.accept(properties);
		properties.put("meterId", METER_ID);
		request.addHeader("Content-Type", "application/json");
		request.setPayload(new JSONSerializer().serialize(properties));
		System.out.println(apiClient.executeRequest(request, 200).getBody());
	}
}
