package com.discovergy.apiclient.examples;

import java.io.IOException;
import java.util.concurrent.ExecutionException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.eclipse.jetty.server.Request;
import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.server.handler.AbstractHandler;

import com.discovergy.apiclient.DiscovergyApiClient;
import com.github.scribejava.core.model.Verb;

public class WebsiteAccessCodeExample extends AbstractHandler {

	private static final String CLIENT_ID = "exampleApiClient";
	private static final String CLIENT_EMAIL = "user@example.org";
	private static final int EXAMPLE_SERVER_PORT = 8083;

	private static final String PORTAL_ADDRESS = "https://my.discovergy.com";

	private DiscovergyApiClient apiClient;

	public WebsiteAccessCodeExample() throws Exception {
		apiClient = new DiscovergyApiClient(CLIENT_ID);
	}

	@Override
	public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		String accessCode;
		try {
			accessCode = apiClient.executeRequest(apiClient.createRequest(Verb.GET, String.format("/website_access_code?email=%s", CLIENT_EMAIL)), 200)
					.getBody();
		} catch (InterruptedException e) {
			e.printStackTrace();
			return;
		} catch (ExecutionException e) {
			e.printStackTrace();
			return;
		}

		String accessURL = String.format("%s/?email=%s&code=%s", PORTAL_ADDRESS, CLIENT_EMAIL, accessCode);
		System.out.println("URL to be embedded in an iframe: " + accessURL);

		response.setContentType("text/html;charset=utf-8");
		response.setStatus(HttpServletResponse.SC_OK);
		baseRequest.setHandled(true);
		response.getWriter()
				.println("<!doctype html>" + //
						"<html><head><title>Discovergy iframe Example</title></head>" + //
						"<body style='background-color: #ddd'>" + //
						"<h1>Hello, I'm a surrounding webpage.</h1>" + //
						"<iframe src='" + accessURL + "' width='100%' height='800px'>" + //
						"</body></html>");
	}

	public static void main(String[] args) throws Exception {
		Server server = new Server(EXAMPLE_SERVER_PORT);
		server.setHandler(new WebsiteAccessCodeExample());

		server.start();
		System.out.println(String.format("Server started. Open http://localhost:%d to see the example.", EXAMPLE_SERVER_PORT));
		server.join();
	}
}
